<div id="{{ chart.id }}" class="chart">
    <script class="chart-info" type="application/json">
        {
            "type": "{{ chart.type }}",
            "options": {{ chart.options_json }},
            "data": {{ chart.data_json }},
            "event_listeners": {{ chart.event_listeners }}
        }
    </script>
</div>